package Weed::Field::MFNode;
use strict;
use warnings;

our $VERSION = '0.0011';

use Weed;

our $DESCRIPTION = 'MFNode : X3DArrayField { }';

1;
__END__
